dim=3;d=3;
[geodir,meshdir]=fc_vfemp1.default_directories(dim);
N=20;
geofile=[geodir,filesep,'cylinderkey.geo'];

fprintf('1. Building the mesh using GMSH\n');
meshfile=gmsh.buildmesh(geofile,N,'d',d,'geodir',geodir,'meshdir',meshdir);
Th=siMesh(meshfile,'dim',3);
fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());

fprintf('2.a Setting 3D potential velocity/flow BVP\n');
d=3;dim=3;
Lop=Loperator(dim,d, {1,[],[];[],1,[];[],[],1},[],[],[]);
bvpFlow=BVP(Th,PDEelt(Lop));
bvpFlow.setDirichlet(1021,1.);
bvpFlow.setDirichlet(2021,1.);
bvpFlow.setDirichlet(1020,-1.);
bvpFlow.setDirichlet(2020,-1.);
fprintf('2.b Solving 3D potential velocity/flow BVP\n')
Phi=bvpFlow.solve();
fprintf('3. Computing 3D velocity flow\n');
Lop=Loperator(dim,d,[],[],{1,0,0},[]);
V{1}=Lop.apply(Th,Phi);
Lop=Loperator(dim,d,[],[],{0,1,0},[]);
V{2}=Lop.apply(Th,Phi);
Lop=Loperator(dim,d,[],[],{0,0,1},[]);
V{3}=Lop.apply(Th,Phi);
fprintf('3. Set 3D stationnary heat P.D.E. with potential flow\n');
af=@(x,y,z) 1+(z-1).^2;
Lop=Loperator(dim,d, {af,[],[];[],af,[];[],[],af},[], {V{1},V{2},V{3}},0.01);
bvpHeat=BVP(Th,PDEelt(Lop));
bvpHeat.setDirichlet(1020,30.);
bvpHeat.setDirichlet(2020,30.);
bvpHeat.setDirichlet(10, @(x,y,z) 10*(abs(z-1)>0.5));
fprintf('4. Solve 3d stationnary heat P.D.E. with potential flow\n');
U=bvpHeat.solve();
fprintf('5. Graphic representations\n');
close all
options=fc_tools.graphics.DisplayFigures('nfig',7);
interpreter=@(x) fc_tools.graphics.interpreter(x);
isorange=linspace(min(Phi),max(Phi),20);
isOctave=fc_tools.comp.isOctave();

figure(1)
colormap(jet)
Th.plot(Phi,'d',2,'FaceColor','interp','EdgeColor','none')
hold on
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
Th.plotiso(Phi,'isorange',isorange,'Color','w')
axis off,axis image
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$\Phi$'),options.title{:},options.interpreter{:})
if ~isOctave(),camzoom(1.3);end

figure(2)
colormap(jet)
VelocityMagnitude=sqrt(V{1}.^2+V{2}.^2+V{3}.^2);
mV=max(VelocityMagnitude);
Th.plotmesh('d',2,'labels',[10,11,31],'FaceColor',0.8*[1,1,1],'EdgeColor',0.9*[1,1,1])
hold on,axis image, axis off
Th.plotVectorField(V,'colordata',U,'scale',2*Th.get_h()/mV,'freq',2)
caxis([min(U),max(U)])
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
if ~isOctave(),camzoom(1.3);end

figure(3)
colormap(jet)
VelocityMagnitude=sqrt(V{1}.^2+V{2}.^2+V{3}.^2);
mV=max(VelocityMagnitude);
Th.plotmesh('d',2,'labels',[10,11,31],'FaceColor',0.8*[1,1,1],'EdgeColor',0.9*[1,1,1])
hold on,axis image, axis off
Th.plotVectorField(V,'colordata',U,'scale',2*Th.get_h()/mV,'freq',2)
caxis([min(U),max(U)])
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
view(-109,26)
if ~isOctave(),camzoom(1.3);end


isorange=linspace(min(U),max(U),20);
figure(4)
colormap(jet)
Th.plot(U,'d',2,'FaceColor','interp','EdgeColor','none')
hold on,axis image, axis off
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
Th.plotiso(U,'isorange',isorange,'Color','w')
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
if ~isOctave(),camzoom(1.3);end

figure(5)
colormap(jet)
VelocityMagnitude=sqrt(V{1}.^2+V{2}.^2+V{3}.^2);
mV=max(VelocityMagnitude);
Th.plotmesh('d',2,'labels',[10,11,31],'FaceColor',0.8*[1,1,1],'EdgeColor',0.9*[1,1,1])
hold on,axis image, axis off
Th.plotVectorField(V,'colordata',U,'scale',1.3*Th.get_h()/mV,'freq',2)
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
axis image, axis off
if ~isOctave(),camzoom(1.3);end

figure(6)
colormap(jet)
axis off,axis image
Th.plot(U,'d',2,'labels',[10,11,31,1000,1020,1021,2000,2020,2021],'FaceColor','interp','EdgeColor','none')
hold on,axis image, axis off
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
Th.plotiso(U,'labels',[10,11,31,1000,1020,1021,2000,2020,2021],'isorange',isorange,'Color','w')
P1=fc_tools.graphics.PlaneCoefs([0 0 1],[0 0 1]);
Th.slice(U,P1,'FaceColor','interp')
Th.sliceiso(U,P1,'isorange',isorange,'Color','w')
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
view(-81,30)

figure(7)
colormap(jet)
P=fc_tools.graphics.PlaneCoefs([0 0 1],[0 1 1]);
Th.slice(U,P, 'FaceColor','interp', 'EdgeColor','none')
axis off,axis image,hold on
Th.plot(U,'d',2,'labels',[1000,2000], 'FaceColor','interp', 'EdgeColor','none')
caxis([min(U),max(U)])
isorange=linspace(min(U),max(U),10);
Th.plot(U,'d',2,'labels',[10,11,31], 'FaceColor','none', 'EdgeColor','interp')
Th.plotiso(U,'labels',[1000,2000], 'isorange',isorange, 'color','w')
Th.sliceiso(U,P,'isorange',isorange, 'color','w')
view(-114,20)
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})